package com.aliyun.alink.devicesdk.demo;

import com.aliyun.alink.linkkit.api.LinkKit;
import com.aliyun.alink.linksdk.cmp.api.CommonResource;
import com.aliyun.alink.linksdk.cmp.api.ResourceRequest;
import com.aliyun.alink.linksdk.cmp.connect.channel.MqttPublishRequest;
import com.aliyun.alink.linksdk.cmp.connect.channel.MqttResource;
import com.aliyun.alink.linksdk.cmp.connect.channel.MqttSubscribeRequest;
import com.aliyun.alink.linksdk.cmp.core.base.ARequest;
import com.aliyun.alink.linksdk.cmp.core.base.AResource;
import com.aliyun.alink.linksdk.cmp.core.base.AResponse;
import com.aliyun.alink.linksdk.cmp.core.listener.*;
import com.aliyun.alink.linksdk.tools.AError;
import com.aliyun.alink.linksdk.tools.ALog;

public class MqttSample extends BaseSample {
    final static String TAG = "MqttSample";

    public MqttSample(String pk, String dn) {
        super(pk, dn);
    }

    /**
     * 发布接口示例
     */
    public void publish() {
        MqttPublishRequest request = new MqttPublishRequest();
        // Topic您需根据实际场景填写
        request.topic = "/" + productKey + "/" + deviceName + "/user/update";
        request.qos = 0;
        request.payloadObj = "{\\\"id\\\":\\\"1\\\",\\\"version\\\":\\\"1.0\\\",\\\"params\\\":{\\\"LightSwitch\\\":0}}";
        LinkKit.getInstance().publish(request, new IConnectSendListener() {
            @Override
            public void onResponse(ARequest aRequest, AResponse aResponse) {
                // 发布结果
                ALog.d(TAG, "onResponse " + (aResponse == null ? "" : aResponse.data));
            }

            @Override
            public void onFailure(ARequest aRequest, AError aError) {
                // 发布失败
                ALog.d(TAG, "onFailure " + (aError == null ? "" : (aError.getCode() + aError.getMsg())));
            }
        });
    }

    /**
     * 订阅接口示例
     */
    public void subscribe() {
        MqttSubscribeRequest request = new MqttSubscribeRequest();
        // topic 您需根据实际场景填写
        request.topic = "/" + productKey + "/" + deviceName + "/user/get";
        request.isSubscribe = true;
        LinkKit.getInstance().subscribe(request, new IConnectSubscribeListener() {
            @Override
            public void onSuccess() {
                // 订阅成功
                ALog.d(TAG, "onSuccess ");
            }

            @Override
            public void onFailure(AError aError) {
                // 订阅失败
                ALog.d(TAG, "onFailure " + getError(aError));
            }
        });
    }

    /**
     * 取消订阅接口示例
     */
    public void unSubscribe() {
        MqttSubscribeRequest request = new MqttSubscribeRequest();
        // Topic用户根据实际场景填写
        request.topic = "/sys/" + productKey + "/" + deviceName + "/thing/deviceinfo/update";
        request.isSubscribe = false;
        LinkKit.getInstance().unsubscribe(request, new IConnectUnscribeListener() {
            @Override
            public void onSuccess() {
                // 取消订阅成功
                ALog.d(TAG, "onSuccess ");
            }

            @Override
            public void onFailure(AError aError) {
                // 取消订阅失败
                ALog.d(TAG, "onFailure " + getError(aError));
            }
        });
    }

}
